from pydantic import BaseModel

class UserIdentity(BaseModel):
    """
    Represents strongly-typed user identity information, regardless of
    the identity provider.
    """
    name: str = None
    user_name: str = None
    upn: str = None
    user_id: str = None

    @staticmethod
    def from_json(json_dict):
        if json_dict is None:
            return None
        else:
            return UserIdentity(
                name=json_dict['name'],
                user_name=json_dict['user_name'],
                upn=json_dict['upn'],
                user_id=json_dict['user_id']
            )



from typing import List
from dataclasses import dataclass

from foundationallm.models.orchestration import ContentArtifact

@dataclass
class FoundationaLLMToolResult:
    """A class to represent the result of a FoundationaLLM tool call."""

    content: str
    """The content of the tool result."""

    content_artifacts: List[ContentArtifact]
    """A list of content artifacts associated with the tool result."""

    input_tokens: int
    """The number of input tokens used in the tool call."""

    output_tokens: int
    """The number of output tokens generated by the tool call."""


from pydantic import BaseModel, Field
from typing import List, Optional

from foundationallm.models.orchestration import ContentArtifact, AttachmentDetail

class MessageHistoryItem(BaseModel):
    """
        Represents an historic message sender and text item.

        Parameters
        ----------
        sender : str
            The sender of the message (e.g., "Agent", "User")
        text : str
            The message text.
    """
    sender: str
    text: str
    content_artifacts : Optional[List[ContentArtifact]] = []
    attachments : Optional[List[AttachmentDetail]] = []



from enum import Enum

class ResourceProviderNames(str, Enum):
    """The names of the FoundationaLLM resource providers."""
    FOUNDATIONALLM_AIMODEL = 'FoundationaLLM.AIModel'
    FOUNDATIONALLM_AZUREAI = 'FoundationaLLM.AzureAI'
    FOUNDATIONALLM_PROMPT = 'FoundationaLLM.Prompt'
    FOUNDATIONALLM_VECTORIZATION = 'FoundationaLLM.Vectorization'



from pydantic import BaseModel, Field
from typing import Any, Self, Optional
from foundationallm.utils import ObjectUtils
from foundationallm.langchain.exceptions import LangChainException

class AgentWorkflowAIModel(BaseModel):
    """
    The base class used for a workflow AIModel resource and associated overrides.
    """
    ai_model_object_id: str = Field(description="The object ID of the AI model object for the workflow.")    
    model_parameters: Optional[dict] = Field(default={}, description="A dictionary containing override values for model parameters.")

    @staticmethod
    def from_object(obj: Any) -> Self:

        agent_workflow_ai_model: AgentWorkflowAIModel = None

        try:
            agent_workflow_ai_model = AgentWorkflowAIModel(**ObjectUtils.translate_keys(obj))
        except Exception as e:
            raise LangChainException(f"The Agent Workflow AI model object provided is invalid. {str(e)}", 400)
        
        if agent_workflow_ai_model is None:
            raise LangChainException("The Agent Workflow AI model object provided is invalid.", 400)

        return agent_workflow_ai_model



from foundationallm.models.resource_providers.ai_models import AIModelBase, AIModelTypes

class CompletionAIModel(AIModelBase):
    """
    A completion AI model.
    """
    type: str = AIModelTypes.COMPLETION



from pydantic import BaseModel, Field
from typing import Optional

class LongRunningOperationLogEntry(BaseModel):
    """
    Represents an entry in the operation execution log.
    """
    id: str = Field(description='The unique id of the log entry.')
    type: str = Field(description='The type of log entry')
    operation_id: str = Field(description='The unique id of the operation.')
    time_stamp: str = Field(description='The timestamp of the log entry.')
    status: str = Field(description='The status of the operation at the time of the log entry.')
    status_message: str = Field(description='The status message of the log entry.')
    upn: Optional[str] = Field(default=None, description='The user principal name of the user who initiated the operation.')
